<?php

namespace Drupal\multilingual_exclude\Routing;

use Drupal\Core\Routing\RouteSubscriberBase;
use Drupal\Core\Routing\RoutingEvents;
use Symfony\Component\Routing\RouteCollection;

/**
 * Alters existing routes to be admin routes.
 */
class MultilingualExcludeRouteAlter extends RouteSubscriberBase {

  /**
   * {@inheritDoc}
   */
  public static function getSubscribedEvents(): array {

    // Route priority is 0 by default, if not provided.
    // Providing a negative number ensures all routes are available.
    // When this number is greater than -110, dashboards layout builder
    // routes are not yet created.
    return [
      RoutingEvents::ALTER => ['onAlterRoutes', -1025],
    ];
  }

  /**
   * {@inheritDoc}
   */
  protected function alterRoutes(RouteCollection $collection): void {

    // Get the config from the multilingual exclude settings.
    $config = \Drupal::config('multilingual_exclude.settings');

    // Break apart the routes that are separated by a comma.
    $routes = $config->get('routes');

    // Ensure that we have some routes as a setting.
    if (is_array($routes)) {

      // Step through each route and ad admin route.
      foreach ($routes as $route) {

        // Ensure there are no spaces in the route name.
        $route_name = str_replace(' ', '', $route['route']);

        // Get the actual route.
        $route = $collection->get($route_name);

        // Set the route to admin, so that it does not translate the page.
        $route?->setOption('_admin_route', TRUE);
      }
    }
  }

}
