<?php

namespace Drupal\multilingual_exclude\Theme;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Theme\ThemeManagerInterface;
use Drupal\Core\Theme\ThemeNegotiatorInterface;

/**
 * Multilingual exclude theme negotiator.
 */
class MultilingualExcludeThemeNegotiator implements ThemeNegotiatorInterface {

  /**
   * Constructor.
   *
   * @param \Drupal\Core\Theme\ThemeManagerInterface $theme_manager
   *   Theme manager.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   Config factory.
   */
  public function __construct(
    protected ThemeManagerInterface $theme_manager,
    protected ConfigFactoryInterface $configFactory,
  ) {}

  /**
   * {@inheritDoc}
   */
  public function applies(RouteMatchInterface $route_match) {

    // Get the config from the multilingual exclude settings.
    $config = \Drupal::config('multilingual_exclude.settings');

    // Get the routes from the config.
    $routes = $config->get('routes');

    // Ensure that we have some routes as a setting.
    if (is_array($routes)) {

      // Step through each of the routes and get the route info.
      foreach ($routes as $route) {
        $routes_to_include[] = $route['route'];
      }

      // If this is in the routes config, return true, which will
      // modify the theme to use for this route.
      if (
        in_array(
          $route_match->getRouteName(),
          $routes_to_include
        )
      ) {
        return TRUE;
      }
    }

    // Return false otherwise, to use the default for the route.
    return FALSE;
  }

  /**
   * {@inheritDoc}
   */
  public function determineActiveTheme(RouteMatchInterface $route_match) {

    // Get the config from the multilingual exclude settings.
    $config = \Drupal::config('multilingual_exclude.settings');

    // Get the routes from the config.
    $routes = $config->get('routes');

    // Step through each of the routes and if it matches the route match,
    // return the theme that it is associated with.
    foreach ($routes as $route) {
      if ($route['route'] === $route_match->getRouteName()) {
        return $route['theme'];
      }
    }

    // Return the default theme, if there is no setting.
    return $this->configFactory->get('system.theme')->get('default');
  }

}

